@@ -66,6 +66,7 @@ ListScramSecretsPaginatorName = Literal["list_scram_secrets"]
 NodeTypeType = Literal["BROKER"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -98,6 +99,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
